/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package controller;

import cart.ShoppingCart;
import entity.Customer;
import entity.CustomerOrder;
import entity.OrderedProduct;
import entity.Product;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import javax.persistence.EntityManager;
import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.mockito.Mockito.*;
import org.mockito.invocation.InvocationOnMock;
import org.mockito.stubbing.Answer;
import session.CustomerOrderFacade;
import session.OrderManager;
import session.OrderedProductFacade;
import session.ProductFacade;

/**
 *
 * @author User
 */
public class ControllerServletTopDownITLevel1Phase1 {
    
    public ControllerServletTopDownITLevel1Phase1() {
    }
    
    /**
     * Test of processRequest method, of class AdminServlet.
     */
    @Test
    public void testDoPostPurchase() throws Exception {
        // given
        // top komponenta L1
        ControllerServlet controllerServlet = new ControllerServlet();
        // komponente L2
        //Validator validator = new Validator();
        OrderManager orderManager = new OrderManager();
        ShoppingCart cart = new ShoppingCart();
        
        // popunjavanje podataka u objektu klase ShoppingCart
        Product bookProduct = new Product(1, "Prohujalo s vihorom", new BigDecimal(300), new Date());
        Product bubbleGumProduct = new Product(2, "Orbit Mentol", new BigDecimal(0.55), new Date());
        cart.addItem(bookProduct);
        cart.addItem(bookProduct);
        cart.addItem(bookProduct);
        cart.addItem(bubbleGumProduct);
        
        Customer customer = 
                new Customer(1, "Ime Prezime", "ime@gmail.com", "+381 63 2212-333", "Adresa 1", "B", "1234-1234-1234");
        CustomerOrder order = new CustomerOrder(200, new BigDecimal(1500.55), new Date(), 200);
        order.setCustomer(customer);
        
        // povezivanje
        controllerServlet.orderManager = orderManager;
        
        /// priprema zavisnih objekata koji nisu nasi moduli
        final String PATH_REQUESTED = "/purchase";
        HttpServletRequest mockedRequest = mock(HttpServletRequest.class);
        when(mockedRequest.getServletPath()).thenReturn(PATH_REQUESTED);
        RequestDispatcher mockedRequestDispatcher = mock(RequestDispatcher.class);
        when(mockedRequest.getRequestDispatcher(anyString())).thenReturn(mockedRequestDispatcher);
        
        // priprema za cart
        HttpSession mockedSession = mock(HttpSession.class);
        when(mockedRequest.getSession()).thenReturn(mockedSession);
        when(mockedSession.getAttribute("cart")).thenReturn(cart);
        
        // priprema za request.getParameter....
        when(mockedRequest.getParameter("name")).thenReturn("Ime Prezime");
        when(mockedRequest.getParameter("email")).thenReturn("ime@gmail.com");
        when(mockedRequest.getParameter("phone")).thenReturn("+381 63 2212-333");
        when(mockedRequest.getParameter("address")).thenReturn("Adresa 1");
        when(mockedRequest.getParameter("cityRegion")).thenReturn("B");
        when(mockedRequest.getParameter("creditcard")).thenReturn("1234-1234-1234");
        
        // poziva se int orderId = orderManager.placeOrder(name, email, phone, address, cityRegion, ccNumber, cart);
        // unutar njega potrebno je mock-ovati samo EntityManager jer se ostale komponente ne koriste
        EntityManager emMock = mock(EntityManager.class);
        orderManager.em = emMock;
        // mock-ujemo poziv em.persist(order) iz OrderManagera
        // jer je bitno da order dobije id
        doAnswer(new Answer<Void>() {
            public Void answer(InvocationOnMock invocation) {
              Object[] args = invocation.getArguments();
              if (args[0] instanceof CustomerOrder) {
                CustomerOrder order = (CustomerOrder) args[0];
                order.setId(789);
              }
              return null;
            }
        }).when(emMock).persist(any(CustomerOrder.class));
        // sledece se poziva Map orderMap = orderManager.getOrderDetails(orderId);
        // unutar getOrderDetails poziva se CustomerOrder order = customerOrderFacade.find(orderId);
        // mockujemo customerOrderFacade
        CustomerOrderFacade cofMock = mock(CustomerOrderFacade.class);
        when(cofMock.find(789)).thenReturn(order);
        // unutar getOrderDetails sledeca linija od interesa je 
        // List<OrderedProduct> orderedProducts = orderedProductFacade.findByOrderId(orderId);
        // mockujemo orderedProductFacade
        OrderedProductFacade opfMock = mock(OrderedProductFacade.class);
        OrderedProduct opBook = new OrderedProduct(789, 1);
        opBook.setQuantity((short)3);
        OrderedProduct opBubbleGum = new OrderedProduct(789, 2);
        opBubbleGum.setQuantity((short)1);
        
        final ArrayList<OrderedProduct> orderedProducts = new ArrayList<OrderedProduct>();
        orderedProducts.add(opBook);
        orderedProducts.add(opBubbleGum);
        when(opfMock.findByOrderId(789)).thenReturn(orderedProducts);
        // unutar getOrderDetails sledeca linija od interesa je 
        // Product p = (Product) productFacade.find(op.getOrderedProductPK().getProductId());
        // mockujemo productFacade
        ProductFacade pfMock = mock(ProductFacade.class);
        when(pfMock.find(1)).thenReturn(bookProduct);
        when(pfMock.find(2)).thenReturn(bubbleGumProduct);
        
        Product[] productsArray = { bookProduct, bubbleGumProduct };
        List<Product> products = Arrays.asList(productsArray);
        
        HttpServletResponse mockedResponse = mock(HttpServletResponse.class);
        
        orderManager.customerOrderFacade = cofMock;
        orderManager.orderedProductFacade = opfMock;
        orderManager.productFacade = pfMock;
        
        // when
        controllerServlet.doPost(mockedRequest, mockedResponse);
        verify(mockedSession).invalidate();
        verify(mockedRequest).getRequestDispatcher("/WEB-INF/view/confirmation.jsp");
        verify(mockedRequest).setAttribute("customer", customer);
        verify(mockedRequest).setAttribute("products", products);
        verify(mockedRequest).setAttribute("orderRecord", order);
        verify(mockedRequest).setAttribute("orderedProducts", orderedProducts);
    }
    
}